@@ -26,6 +26,10 @@ L<SPVM::IO::Socket> class has methods for sockets.
 
 =head1 Details
 
+=head2 Porting
+
+This class is a Perl's L<IO::Socket|IO::Socket> porting to L<SPVM>.
+
 =head2 Socket Constant Values
 
 See L<Sys::Socket::Constant|SPVM::Sys::Socket::Constant> about constant values for sockets.
@@ -72,7 +76,7 @@ A timeout seconds for system calls that would set C<errno> to C<EWOULDBLOCK>, li
 
 =head2 Listen
 
-  has Listen : protected int;
+C<has Listen : protected int;>
 
 =head1 Class Methods
 
@@ -84,6 +88,8 @@ The socket is set to non-blocking mode.
 
 Options:
 
+The following options are available adding to the options for L<IO::Handle#new|SPVM::IO::Handle/"new"> method.
+
 =over 2
 
 =item * Domain : Int
@@ -152,74 +158,6 @@ Exceptions:
 
 Exceptions thrown by L<Sys#socket|Sys/"socket"> method could be thrown.
 
-=head2 recv
-
-C<method recv : int ($buffer : mutable string, $length : int = -1, $flags : int = 0, $buf_offset : int = 0);>
-
-Calls L</"recvfrom"> method with $from set to C<undef> and returns its return value.
-
-Exceptions:
-
-Exceptions thrown by L</"recvfrom"> method could be thrown.
-
-=head2 recvfrom
-
-C<method recvfrom : int ($buffer : mutable string, $length : int, $flags : int, $from_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[], $buf_offset : int = 0)>
-
-=head2 send
-
-C<method send : int ($buffer : string, $flags : int = 0, $length : int = -1, $buf_offset : int = 0);>
-
-Calls L</"sendto"> method with $to set to C<undef> and returns its return value.
-
-Exceptions:
-
-Exceptions thrown by L</"sendto"> method could be thrown.
-
-=head2 sendto
-
-C<method sendto : int ($buffer : string, $flags : int, $to : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $length : int = -1, $buf_offset : int = 0);>
-
-=head2 close
-
-C<method close : int ();>
-
-Closes the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
-
-Exceptions:
-
-If this socket is not opened or already closed, an excetpion is thrown.
-
-=head2 sockname
-
-C<method sockname : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
-
-Returns the local socket address of the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
-
-This method calls L<Sys#getsockname|SPVM::Sys/"getsockname"> method.
-
-Exceptions:
-
-Exceptions thrown by L<Sys#getsockname|SPVM::Sys/"getsockname"> method could be thrown.
-
-=head2 peername
-
-C<method peername : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
-
-Returns the remote socket address of the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
-
-This method calls L<Sys#getpeername|SPVM::Sys/"getpeername"> method.
-
-Exceptions:
-
-Exceptions thrown by L<Sys#getpeername|SPVM::Sys/"getpeername"> method could be thrown.
-
-=head2 connected
-
-C<method connected : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
-
-If L</"peername"> method does not throw an exception, returns the return value, otherwise returns undef.
-
 =head2 shutdown
 
 C<method shutdown : void ($how : int);>
@@ -244,17 +182,15 @@ Exceptions:
 
 Exceptions thrown by L<Sys#shutdown|SPVM::Sys/"shutdown"> method could be thrown.
 
-=head2 atmark
+=head2 close
 
-C<method atmark : int ();>
+C<method close : int ();>
 
-If the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field is currently positioned at the urgent data mark, returns 1, otherwise returns 0.
-
-This method calls L<Sys::Socket#sockatmark|SPVM::Sys::Socket/"sockatmark"> method.
+Closes the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
 
 Exceptions:
 
-Exceptions thrown by L<Sys::Socket#sockatmark|SPVM::Sys::Socket/"sockatmark"> method could be thrown.
+If this socket is not opened or already closed, an excetpion is thrown.
 
 =head2 bind
 
@@ -280,69 +216,157 @@ Exceptions:
 
 Exceptions thrown by L<Sys#listen|SPVM::Sys|/"listen"> method could be thrown.
 
-=head2 peerport
+=head2 accept
 
-C<method peerport : int ();>
+C<method accept : L<IO::Socket|SPVM::IO::Socket> ($peer_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[] = undef);>
 
-This method is implemented in a child class.
+Does the same thing that L<accept|https://linux.die.net/man/2/accept> system call does given the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
+
+This method calls L<Sys#accept|SPVM::Sys|/"accept">.
 
 Exceptions:
 
-Not implemented.
+Exceptions thrown by L<Sys#accept|SPVM::Sys|/"accept"> method could be thrown.
 
-=head2 peerhost
+=head2 recvfrom
 
-C<method peerhost : string ();>
+C<method recvfrom : int ($buffer : mutable string, $length : int, $flags : int, $from_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[], $offset : int = 0)>
 
-This method is implemented in a child class.
+=head2 sendto
+
+C<method sendto : int ($buffer : string, $flags : int, $to : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $length : int = -1, $offset : int = 0);>
+
+=head2 recv
+
+C<method recv : int ($buffer : mutable string, $length : int = -1, $flags : int = 0, $offset : int = 0);>
+
+Calls L</"recvfrom"> method given the arguments to this method with $from_ref set to C<undef> and returns its return value.
 
 Exceptions:
 
-Not implemented.
+Exceptions thrown by L</"recvfrom"> method could be thrown.
+
+=head2 send
+
+C<method send : int ($buffer : string, $flags : int = 0, $length : int = -1, $offset : int = 0);>
+
+Calls L</"sendto"> method given the arguments to this method with $to set to C<undef> and returns its return value.
+
+Exceptions:
+
+Exceptions thrown by L</"sendto"> method could be thrown.
+
+=head2 read
+
+C<method read : int ($buffer : mutable string, $length : int = -1, $offset : int = 0);>
+
+Reads the length $length of data from the stream associated with the file descriptoer L</"FD"> and store it to the offset $offset position of the string $string.
+
+And returns the read length.
+
+This method calls L</"recv"> method given the arguments given to this method and returns its return values.
 
 =head2 write
 
-C<method write : int ($string : string, $length : int = -1, $offset : int = 0);>
+C<method write : int ($buffer : string, $length : int = -1, $offset : int = 0);>
 
-Writes the length $length from the offset $offset of the string $string to the stream associated with the file descriptoer L</"FD">.
+Writes the length $length from the offset $offset of the string $buffer to the stream associated with the file descriptoer L</"FD">.
 
-This method calls L</"send"> method with $buffer set to $string, $flags set to 0, $length set to $length, and $buf_offset set to $offset.
+And returns the write length.
 
-And returns its return value.
+This method calls L</"send"> method given the arguments given to this method and returns its return values.
 
 Exceptions:
 
 Exceptions thrown by L</"send"> method could be thrown.
 
-=head2 read
+=head2 sockname
 
-C<method read : int ($string : mutable string, $length : int = -1, $offset : int = 0);>
+C<method sockname : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
+
+Returns the local socket address of the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
+
+This method calls L<Sys#getsockname|SPVM::Sys/"getsockname"> method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#getsockname|SPVM::Sys/"getsockname"> method could be thrown.
+
+=head2 peername
+
+C<method peername : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
+
+Returns the peer socket address of the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
+
+This method calls L<Sys#getpeername|SPVM::Sys/"getpeername"> method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#getpeername|SPVM::Sys/"getpeername"> method could be thrown.
+
+=head2 connected
+
+C<method connected : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
+
+If L</"peername"> method does not throw an exception, returns the return value, otherwise returns undef.
+
+=head2 atmark
+
+C<method atmark : int ();>
+
+If the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field is currently positioned at the urgent data mark, returns 1, otherwise returns 0.
+
+This method calls L<Sys::Socket#sockatmark|SPVM::Sys::Socket/"sockatmark"> method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::Socket#sockatmark|SPVM::Sys::Socket/"sockatmark"> method could be thrown.
 
 =head2 sockopt
 
-C<method sockopt : int ($level : int, $optname : int);>
+C<method sockopt : int ($level : int, $option_name : int);>
+
+Gets a socket option of the file descriptor stored in L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field given the socket level $level and the option name $option_name.
+
+This method calls L<Sys#getsockopt|SPVM::Sys/"getsockopt"> method given the arguments given to this method and returns its return value.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#getsockopt|SPVM::Sys/"getsockopt"> method could be thrown.
 
 =head2 setsockopt
 
-C<method setsockopt : void ($level : int, $optname : int, $optval : object of string|Int)
+C<method setsockopt : void ($level : int, $option_name : int, $option_value : object of string|L<Int|SPVM::Int>);>
+
+Sets a socket option of the file descriptor stored in L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field given the socket level $level, the option name $option_name, and the option value $option_value.
+
+This method calls L<Sys#setsockopt|SPVM::Sys/"setsockopt"> method given the arguments given to this method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#setsockopt|SPVM::Sys/"setsockopt"> method could be thrown.
+
+=head1 Well Known Child Classes
+
+=over 2
+
+=item * L<IO::Socket::IP|SPVM::IO::Socket::IP>
+
+=item * L<IO::Socket::INET|SPVM::IO::Socket::INET>
+
+=item * L<IO::Socket::INET6|SPVM::IO::Socket::INET6>
+
+=back
 
 =head1 See Also
 
-=head2 Sys::Socket
+=over 2
 
-L<Sys::Socket|SPVM::Sys::Socket>
+=item * L<Sys::Socket|SPVM::Sys::Socket>
 
-=head2 Sys::Socket::Constant
+=item * L<Sys::Socket::Constant|SPVM::Sys::Socket::Constant>
 
-L<Sys::Socket::Constant|SPVM::Sys::Socket::Constant>
-
-=head2 IO::Socket::INET
-
-L<IO::Socket::INET|SPVM::IO::Socket::INET>
-
-=head2 Perl's IO::Socket
-
-C<IO::Socket> is a Perl's L<IO::Socket|IO::Socket> porting to L<SPVM>.
+=back
 
 =head1 Copyright & License
 
